@@ -46,14 +46,19 @@ gchar *module_label_str = N_("_Module path:");
 static void
 settings_dev_list (GtkComboBox *combo, GstBootImageType ctype)
 {
-	xmlNodePtr  root;
-	xmlNodePtr  part;
-	xmlNodePtr  node;
-	gchar      *type;
-	gchar      *dev;
+	xmlNodePtr    root;
+	xmlNodePtr    part;
+	xmlNodePtr    node;
+	gchar        *type;
+	gchar        *dev;
+	GtkTreeModel *model;
 
 	root = gst_xml_doc_get_root (tool->config);
 	part = gst_xml_element_find_first (root, "partitions");
+
+	model = gtk_combo_box_get_model (combo);
+	gtk_list_store_clear (GTK_LIST_STORE (model));
+
 	for (node = gst_xml_element_find_first (part, "partition");
 	     node; node = gst_xml_element_find_next (node, "partition"))
 	{
@@ -149,7 +154,6 @@ boot_settings_gui_new (BootImage *image, GtkWidget *parent)
 	                  G_CALLBACK (on_boot_append_browse_clicked), (gpointer) gui);
 	g_signal_connect (G_OBJECT (gui->use_password), "clicked",
 			  G_CALLBACK (on_use_password_clicked), (gpointer) gui);
-
 	return gui;
 }
 
@@ -305,6 +309,9 @@ boot_settings_gui_setup (BootSettingsGui *gui, GtkWidget *top)
 	{
 		settings_dev_list (GTK_COMBO_BOX (gui->device), image->type);
 
+		if (!image->new)
+			boot_settings_set_type (gui, type_to_label (image->type));
+
 		if (image->image)
 			gst_ui_entry_set_text (GTK_ENTRY (GTK_BIN (gui->device)->child), image->image);
 	}
