@@ -41,11 +41,10 @@ typedef enum {
 } GstConnectionType;
 
 enum {
+	CONNECTION_LIST_COL_STAT,
 	CONNECTION_LIST_COL_DEV_PIX,
 	CONNECTION_LIST_COL_DEV_TYPE,
 	CONNECTION_LIST_COL_DEVICE,
-	CONNECTION_LIST_COL_STAT,
-	CONNECTION_LIST_COL_DESCR,
 
 	CONNECTION_LIST_COL_DATA,
 	CONNECTION_LIST_COL_LAST
@@ -91,7 +90,6 @@ typedef struct {
 	
 	GstConnectionType type;
 	ActivationType    activation;
-	gboolean          bulb_state;
 
 	gboolean modified;
 	gboolean creating;
@@ -159,7 +157,6 @@ extern GstConnectionErrorType connection_default_gw_check_manual (GstConnection
 extern void connection_default_gw_fix (GstConnection *cxn, GstConnectionErrorType error);
 extern void connection_default_gw_set_manual (GstTool *tool, GstConnection *cxn);
 extern void connection_default_gw_set_auto (GstTool *tool);
-extern void connection_update_complexity (GstTool *tool, GstDialogComplexity complexity);
 extern void connection_actions_set_sensitive (gboolean state);
 extern void connection_free (GstConnection *);
 extern void connection_configure (GstConnection *cxn);
@@ -169,21 +166,28 @@ extern void connection_save_to_node (GstConnection *cxn, xmlNode *node);
 GstConnection *connection_list_get_active (void);
 GstConnection *connection_list_get_by_path (GtkTreePath*);
 void           connection_list_remove     (GstConnection *cxn);
-void           connection_activate        (GstConnection *cxn, gboolean activate);
+void           connection_show_activated  (GstConnection *cxn, gboolean activate);
 void           connection_list_update     (void);
 gboolean       connection_list_has_dialer (GstTool *tool);
 void           connection_list_save       (GstTool *tool);
 void           connection_list_select_connection (GstConnection *cxn);
 void           connection_list_clear      (GstTool *tool);
 
-gboolean connection_config_save (GstConnection*, gboolean);
+gboolean connection_config_save (GstConnection*, GtkWidget*, gboolean);
 void     connection_check_netmask_gui (GtkWidget*, GtkWidget*);
 void     connection_set_modified (GstConnection*, gboolean);
 
 gchar *connection_find_new_device (xmlNodePtr, GstConnectionType);
-gchar*   connection_autodetect_modem (void);
 void connection_set_bcast_and_network (GstConnection *cxn);
 
+gboolean connection_poll_stat (GstTool*);
+gchar*   connection_autodetect_modem (void);
+gchar*   connection_description_from_type (GstConnectionType);
+void     connection_fill_ip_menu (GtkWidget*);
+void     connection_update_ip_config (GstConnection*);
+void     connection_enable (GstConnection*, gboolean);
+void     connection_apply_and_enable (GstTool*, GstConnection*);
+
 gint connection_get_count (GstTool*);
 
 #endif /* CONNECTION_H */
