@@ -87,9 +87,9 @@ create_groups_model (void)
 void
 create_groups_table (void)
 {
-	GtkTreeModel *model;
+	GtkTreeModel     *model;
 	GtkTreeSelection *selection;
-	GtkItemFactory *item_factory;
+	GtkWidget        *popup;
 	
 	model = create_groups_model ();
 	
@@ -103,14 +103,15 @@ create_groups_table (void)
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (groups_table));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 
-	item_factory = popup_item_factory_create (groups_table);
+	popup = popup_menu_create (groups_table);
 	
 	g_signal_connect (G_OBJECT (selection), "changed",
 			  G_CALLBACK (on_table_clicked),
 			  (gpointer) groups_table);
 	g_signal_connect (G_OBJECT (groups_table), "button_press_event",
-			  G_CALLBACK (on_table_button_press),
-			  (gpointer) item_factory);
+			  G_CALLBACK (on_table_button_press), popup);
+	g_signal_connect (G_OBJECT (groups_table), "popup-menu",
+			  G_CALLBACK (on_table_popup_menu), popup);
 }
 
 static char*
@@ -175,21 +176,27 @@ groups_table_set_cursor (gchar *old_group)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gchar *group;
+	gboolean valid;
 	
 	if (old_group == NULL)
-		return;	
-	model = gtk_tree_view_get_model (GTK_TREE_VIEW (groups_table));
-	if (gtk_tree_model_get_iter_first (model, &iter) != TRUE)
 		return;
-	do {
+	
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (groups_table));
+	valid = gtk_tree_model_get_iter_first (model, &iter);
+
+	while (valid) {
 		gtk_tree_model_get (model, &iter, 0, &group, -1);
-		if (strcmp (old_group, group) == 0 ) 
-		{
+
+		if (strcmp (old_group, group) == 0 ) {
 			GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
 			gtk_tree_view_set_cursor (GTK_TREE_VIEW (groups_table), path, NULL, FALSE);
 			gtk_tree_path_free (path);
+
+			return;
 		}
-	} while (gtk_tree_model_iter_next (model, &iter) != FALSE);
+
+		valid = gtk_tree_model_iter_next (model, &iter);
+	}
 }
 
 void
